diff --git a/src/main/java/be/cylab/java/wowa/training/TrainerParameters.java b/src/main/java/be/cylab/java/wowa/training/TrainerParameters.java
index 1f477008c0ba83c8d3d9c0ea4a4348e631857b5f..9c287561b93442f56c9db152430f9f4a72fc32c2 100644
--- a/src/main/java/be/cylab/java/wowa/training/TrainerParameters.java
+++ b/src/main/java/be/cylab/java/wowa/training/TrainerParameters.java
@@ -20,28 +20,27 @@ public class TrainerParameters {
     /**
      * Contains parameters for the WOWA trainer.
      *
      * @param populationSize Size of the population for the Genetic Algorithm (greater than 2)
      * @param crossoverRate Crossover rate for the genetic algorithm. Percentage of the population kept to generate the next generation (1-99)
      * @param mutationRate Mutation rate for the genetic algorithm. percentage of genes mutated in the next generation (1-99)
      * @param selectionMethod Method to select parents for the next generation. RWS or TOS
      * @param maxGenerationNumber Max generation number before the algorithm stop
      */
     public TrainerParameters(
             //Logger logger,
-            int populationSize,
-            int crossoverRate,
-            int mutationRate,
-            int selectionMethod,
-            int maxGenerationNumber
+            int population_size,
+            int crossover_rate,
+            int mutation_rate,
+            int selection_method,
+            int max_generation_number
 
     ) {
         //this.setLogger(logger);
-        this.setPopulationSize(populationSize);
-        this.setCrossoverRate(crossoverRate);
-        this.setMutationRate(mutationRate);
-        this.setSelectionMethod(selectionMethod);
-        this.setSelectionMethod(selectionMethod);
-        this.setMaxGenerationNumber(maxGenerationNumber);
+        this.setPopulationSize(population_size);
+        this.setCrossoverRate(crossover_rate);
+        this.setMutationRate(mutation_rate);
+        this.setSelectionMethod(selection_method);
+        this.setMaxGenerationNumber(max_generation_number);
 
     }
@@ -20,28 +20,27 @@ public class TrainerParameters {
      * Contains parameters for the WOWA trainer.
      *
-     * @param populationSize Size of the population for the Genetic Algorithm (greater than 2)
-     * @param crossoverRate Crossover rate for the genetic algorithm. Percentage of the population kept to generate the next generation (1-99)
-     * @param mutationRate Mutation rate for the genetic algorithm. percentage of genes mutated in the next generation (1-99)
-     * @param selectionMethod Method to select parents for the next generation. RWS or TOS
-     * @param maxGenerationNumber Max generation number before the algorithm stop
+     * @param population_size Size of the population for the Genetic Algorithm (greater than 2)
+     * @param crossover_rate Crossover rate for the genetic algorithm. Percentage of the population kept to generate the next generation (1-99)
+     * @param mutation_rate Mutation rate for the genetic algorithm. percentage of genes mutated in the next generation (1-99)
+     * @param selection_method Method to select parents for the next generation. RWS or TOS
+     * @param max_generation_number Max generation number before the algorithm stop
      */
     public TrainerParameters(